"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lodash = require("lodash");

var _constants = require("./constants");

var _utils = require("../utils");

var _default = (state = {}, {
  type,
  data,
  err,
  key,
  pluralized
}) => {
  if (!key) {
    throw new Error('Key required for managing state');
  }

  const resource = key;
  const resources = pluralized;
  const handlers = {
    [_constants.FETCHING]() {
      return {
        fetching: true
      };
    },

    [_constants.FETCHED]() {
      return { ...state,
        ...data,
        fetchingError: !(0, _utils.isEmpty)(err),
        fetching: false,
        err
      };
    },

    [_constants.UPDATED]() {
      const next = (0, _lodash.get)(data, resource, {});
      const prev = { ...state
      };

      if (resource in prev) {
        prev[resource] = next;
      } else if (resources in prev) {
        prev[resources] = (0, _lodash.get)(prev, resources, []).map(item => next.id === item.id ? next : item);
      }

      return (0, _lodash.merge)({}, prev, data);
    },

    [_constants.CREATED]() {
      if ((0, _utils.isEmpty)(data)) return state;
      const next = (0, _lodash.get)(data, resource, {});
      const prev = { ...state
      };

      if (resource in prev) {
        prev[resource] = next;
      } else {
        prev[resources] = Array.isArray(state[resources]) ? [next, ...state[resources]] : [next];
      }

      return prev;
    },

    /**
     * @TODO:
     * Find better solution.
     */
    [_constants.DELETED]() {
      return (0, _utils.isEmpty)(data) ? state : { ...state,
        [resource]: Array.isArray(state[resource]) ? state[resource].filter(({
          id
        }) => id !== data.id) : null,
        [resources]: Array.isArray(state[resources]) ? state[resources].filter(({
          id
        }) => id !== data.id) : null
      };
    },

    /**
     * @TODO:
     * Find better solution.
     */
    [_constants.DELETED_MANY]() {
      return (0, _utils.isEmpty)(data) ? state : { ...state,
        [resource]: Array.isArray(state[resource]) ? state[resource].filter(({
          id
        }) => !data.ids.includes(id)) : null,
        [resources]: Array.isArray(state[resources]) ? state[resources].filter(({
          id
        }) => !data.ids.includes(id)) : null
      };
    }

  };
  return (0, _utils.getFn)(handlers, type);
};

exports.default = _default;