"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generatePaths = exports.pluralize = exports.makePath = exports.pickForPatch = exports.extractValue = exports.isEmpty = exports.getFn = void 0;

var _lodash = require("lodash");

const getFn = (obj, prop) => prop in obj ? obj[prop]() : new Error('Unknown action');

exports.getFn = getFn;

const isEmpty = obj => obj ? !Object.keys(obj).length : true;

exports.isEmpty = isEmpty;

const extractValue = a => a.map(b => b.value);

exports.extractValue = extractValue;

const pickForPatch = (a, b) => (0, _lodash.pick)(a, Object.keys(b));

exports.pickForPatch = pickForPatch;

const makePath = (a = []) => a.filter(b => b && b !== '/').map(b => {
  const str = String(b);
  const {
    length
  } = str;
  const lastChar = str.substr(-1);
  return lastChar === '/' ? str.substring(length - 1) : str;
}).join('/');

exports.makePath = makePath;

const pluralize = (name = '') => {
  const {
    length
  } = name;
  const lastChar = length - 1;

  if (name.charAt(lastChar) === 'y') {
    return `${name.substring(0, lastChar)}ies`;
  }

  return `${name}s`;
};

exports.pluralize = pluralize;

const generatePaths = pathToName => {
  const [pathToData] = pathToName.split('.');
  return {
    pathToRest: `/${pluralize(pathToData)}`,
    pathToData,
    pathToName
  };
};

exports.generatePaths = generatePaths;